==> pgpoolAdmin-1.0.0.tar.gz: pgpoolAdmin-1.0.0/install/lang/ja.lang.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in Japanese
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Ryuma Ando <ando@ecomas.co.jp>
 * @copyright  2003-2006		PgPool Global Development Group
 * @version    CVS: $Id: ja.lang.php,v 1.1.1.1 2006/08/21 02:15:41 y-asaba Exp $
 */

$message = array(
    'lang' => 'ja',
    'strLang' => '日本語',
    'strNext' => '次へ',
    'strCheck' => 'チェック',
    'strDirectoryCheck' => 'ディレクトリ確認',
    'strParameterCheck' => '管理ツールパラメータ設定',
    'strFinish' => '完了',
    'strPgConfFile' => 'pgpool.confファイル',
    'strPasswordFile' => 'パスワードファイル',
    'strPgmgtFile' => '管理ツール設定ファイル',
    'strTempDir' => 'テンプレートディレクトリ',
    'strPgpoolCommand' => 'Pgpoolコマンド',
    'strPgpoolCommandOption' => 'pgpoolコマンドオプション',
    'strCmdC' => 'クエリキャッシュクリア',
    'strCmdD' => 'デバッグモード',
    'strCmdM' => '停止モード',
    'strCmdN' => '非デーモンモード',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => '空白の場合には無視',
    'strPgpoolLogFile' => 'Pgpoolログファイル',
    'strPcpDir' => 'PCPディレクトリ',
    'strPcpTimeout' => 'PCPタイムアウト',
    'strPcpHostName' => 'PCPホスト名',
    'strPcpRefreshTime' => '更新間隔(0で自動更新しない)',
    'msgCongratulations' => 'おめでとうございます。インストールは終了しました。',
    'msgDeleteInstallDir' => 'を削除してください',
    'msgToTop' => 'トップ画面へ移動'
);

?>

==> pgpoolAdmin-2.3.tar.gz: pgpoolAdmin-2.3/install/lang/ja.lang.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Message catalog in Japanese
 *
 * PHP versions 4 and 5
 *
 * LICENSE: Permission to use, copy, modify, and distribute this software and
 * its documentation for any purpose and without fee is hereby
 * granted, provided that the above copyright notice appear in all
 * copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of the
 * author not be used in advertising or publicity pertaining to
 * distribution of the software without specific, written prior
 * permission. The author makes no representations about the
 * suitability of this software for any purpose.  It is provided "as
 * is" without express or implied warranty.
 *
 * @author     Ryuma Ando <ando@ecomas.co.jp>
 * @copyright  2003-2008		PgPool Global Development Group
 * @version    CVS: $Id: ja.lang.php,v 1.5 2008/02/01 07:06:41 yamaguti Exp $
 */

$message = array(
    'lang' => 'ja',
    'strLang' => '日本語',
    'strNext' => '次へ',
    'strCheck' => 'チェック',
    'strDirectoryCheck' => 'ディレクトリ確認',
    'strParameterCheck' => '管理ツールパラメータ設定',
    'strFinish' => '完了',
    'strPgConfFile' => 'pgpool.confファイル',
    'strPasswordFile' => 'pcp.confファイル',
    'strPgmgtFile' => '管理ツール設定ファイル',
    'strTempDir' => 'テンプレートディレクトリ',
    'strPgpoolCommand' => 'pgpoolコマンド',
    'strPgpoolCommandOption' => 'pgpoolコマンドオプション',
    'strCmdC' => 'クエリキャッシュクリア',
    'strCmdD' => 'デバッグモード',
    'strCmdM' => '停止モード',
    'strCmdN' => '非デーモンモード',
    'strCmdPgpoolFile' => 'pgpool.conf',
    'strCmdPcpFile' => 'pcp.conf',
    'strCmdDesc' => '空白の場合には無視',
    'strPgpoolLogFile' => 'pgpoolログファイル',
    'strPcpDir' => 'PCPディレクトリ',
    'strPcpTimeout' => 'PCPタイムアウト',
    'strPcpHostName' => 'PCPホスト名',
    'strPcpRefreshTime' => '更新間隔(0で自動更新しない)',
    'msgCongratulations' => 'おめでとうございます。インストールは終了しました。',
    'msgDeleteInstallDir' => 'を削除してください',
    'msgToTop' => 'トップ画面へ移動'
);

?>
